<img src="https://github.com/rob-dalton/rob-dalton.github.io/blob/master/images/awspot/awspot_logo.png" alt="awspot-logo" width="420">
<hr>
Command line utility to easily manage Amazon AWS spot resources.
*NOTE: The only available resource type is `ec2`. Spot fleet and EMR management are in progress.*

## Setup
1. [Install and configure awscli.](https://aws.amazon.com/cli/)
2. Run `pip install awspot`

## Usage
Please refer to [the project docs](https://rob-dalton.github.io/awspot) to learn more. 
